@@ -6,7 +6,9 @@ def remove_time_from_date(date_string: Union[datetime, str]) -> str:
     """
     Remove time, i.e. 00:00:00, from a datetime.datetime or string
     :param date_string: datetime.datetime object or string to convert
+    :type date_string: datetime.datetime or str
     :return: str without time, i.e. 2020-08-29
+    :return: str
     """
     if type(date_string) == str:
         date_string = string_to_datetime(date_string=date_string)
@@ -17,7 +19,9 @@ def get_year_from_date(date_string: Union[datetime, str]) -> int:
     """
     Extract year from a datetime.datetime or string
     :param date_string: datetime.datetime object or string
+    :type date_string: datetime.datetime or str
     :return: int of year, i.e. 2020
+    :return: int
     """
     if type(date_string) == str:
         date_string = string_to_datetime(date_string=date_string)
@@ -28,8 +32,11 @@ def string_to_datetime(date_string: str, template: str = "%Y-%m-%dT%H:%M:%S") ->
     """
     Convert a string to a datetime.datetime object
     :param date_string: datetime string to convert
+    :type date_string: str
     :param template: (Optional) datetime template to use when parsing string (Default: "%Y-%m-%dT%H:%M:%S")
+    :type template: str
     :return: datetime.datetime object
+    :rtype: datetime.datetime
     """
     if date_string.endswith('Z'):
         date_string = date_string[:-5]
@@ -40,8 +47,11 @@ def datetime_to_string(datetime_object: datetime, template: str = "%Y-%m-%dT%H:%
     """
     Convert a datetime.datetime object to a string
     :param datetime_object: datetime.datetime object to convert
+    :type datetime_object: datetime.datetime
     :param template: (Optional) datetime template to use when parsing string
+    :type template: str
     :return: str representation of datetime
+    :rtype: str
     """
     return datetime_object.strftime(template)
 
@@ -50,7 +60,9 @@ def adjust_datetime_for_timezone(local_time: datetime) -> datetime:
     """
     Shift datetime.datetime in regards to UTC time
     :param local_time: local time datetime.datetime object
+    :type local_time: datetime.datetime
     :return: Shifted datetime.datetime object
+    :rtype: datetime.datetime
     """
     difference = datetime.now() - datetime.utcnow()
     return local_time - difference
@@ -60,6 +72,7 @@ def hours_difference_in_timezone() -> int:
     """
     Get the hours difference between local and UTC time
     :return: int number of hours
+    :rtype: int
     """
     return int((datetime.utcnow() - datetime.now()).total_seconds() / 60 / 60)
 
@@ -68,7 +81,9 @@ def get_nearest_30_minute_mark(time_format: str = "%Y-%m-%dT%H:%M:%S.000Z") -> s
     """
     Get the most recently past hour or half-hour time
     :param time_format: (Optional) Format of timestamp (Default: "%Y-%m-%dT%H:%M:%S.000Z")
+    :type time_format: str
     :return: str of datetime
+    :rtype: str
     """
     now = datetime.utcnow()
     if now.minute >= 30:
@@ -82,8 +97,11 @@ def get_milliseconds_between_two_hours(start_hour: int, end_hour: int) -> int:
     """
     Get how many milliseconds between two 24-hour hours
     :param start_hour: starting hour (in 24-hour time)
+    :type start_hour: int
     :param end_hour: ending hour (in 24-hour time)
+    :type start_hour: int
     :return: int of milliseconds between the two hours
+    :rtype: int
     """
     start_date = datetime(2020, 1, 1, start_hour, 0)
     if end_hour < start_hour:
@@ -97,7 +115,10 @@ def get_milliseconds_between_two_datetimes(start_datetime: datetime, end_datetim
     """
     Get how many milliseconds between two datetime.datetime objects
     :param start_datetime: starting datetime.datetime object
+    :type start_datetime: datetime.datetime
     :param end_datetime: ending datetime.datetime object
+    :type end_datetime: datetime.datetime
     :return: int of milliseconds between the two datetime.datetime objects
+    :rtype: int
     """
     return int((end_datetime - start_datetime).total_seconds()) * 1000
